#!/bin/bash

##########################################################################
#Aqueduct - Compliance Remediation Content
#Copyright (C) 2011,2012  
#  Vincent C. Passaro (vincent.passaro@gmail.com)
#  Shannon Mitchell (shannon.mitchell@fusiontechnology-llc.com)
#
#This program is free software; you can redistribute it and/or
#modify it under the terms of the GNU General Public License
#as published by the Free Software Foundation; either version 2
#of the License, or (at your option) any later version.
#
#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 51 Franklin Street, Fifth Floor,
#Boston, MA  02110-1301, USA.
##########################################################################

##################### Fusion Technology LLC #############################
# By Shannon Mitchell                                                   #
# Fusion Technology LLC                                                 #
# Shannon[.]Mitchell[@]fusiontechnology-llc[.]com                       #
# www.fusiontechnology-llc.com                                          #
##################### Fusion Technology LLC #############################
#
#  _____________________________________________________________________
# |  Version |   Change Information  |      Author        |    Date    |
# |__________|_______________________|____________________|____________|
# |    1.0   |   Initial Script      | Shannon Mitchell   | 15-jul-2012|
# |          |   Creation            |                    |            |
# |__________|_______________________|____________________|____________|
#	                                                                  
   
	
#######################DISA INFORMATION##################################
# Group ID (Vulid): V-27285
# Group Title: GEN000600-2
# Rule ID: SV-34584r1_rule
# Severity: medium
# Rule Version (STIG-ID): GEN000600-2
# Rule Title: Global settings defined in system-auth must be applied in 
# the pam.d definition files.

#
# Vulnerability Discussion: Pam global requirements are generally defined 
# in the /etc/pam.d/system-auth or /etc/pam.d/system-auth-ac file. In order 
# for the requirements to be applied the file containing them must be 
# included directly or indirectly in each program's definition file in 
# /etc/pam.d


#
# Responsibility: System Administrator
# IAControls: ECSC-1
#
# Check Content:
#
# Verify the system-auth settings are being applied.

# Procedure:
# Verify the additional pam.d requirements are in use.

# The file "/etc/pam.d/system-auth-ac" is auto generated by "authconfig". 
# Any manual changes made to it will be lost next time "authconfig" is run. 
# Check to see if the systems default of the symlink 
# "/etc/pam.d/system-auth" pointing to "/etc/pam.d/system-auth-ac" has been 
# changed.

# ls -l /etc/pam.d/system-auth

# If the symlink points to "/etc/pam.d/system-auth-ac", manual changes 
# cannot be protected. This is a finding.

# grep system-auth-ac /etc/pam.d/system-auth

# The local system-auth file pointed to by "/etc/pam.d/system-auth" must 
# contain "/etc/pam.d/system-auth-ac" for the auth, account, password, and 
# session lines. If it does not then the parameters maintained by 
# "authconfig" will not be applied, this is a finding.
#
# Fix Text: 
#
# In the default distribution of RHEL "/etc/pam.d/system-auth" is a 
# symlink "/etc/pam.d/system-auth-ac" which is an autogenerated file. When 
# a site adds password requirements a new system-auth-local file must be 
# created with only the additional requirements and includes for auth, 
# account, passwd and session pointing to "/etc/pam.d/system-auth-ac". Then 
# the symlink "/etc/system-auth" is modified to point to 
# "/etc/pam.d/system-auth-local". This way any changes made do not get lost 
# when "/etc/pam.d/system-auth-ac" is regenerated and each program's pam.d 
# definition file need only have "include system-auth" for auth, account, 
# passwd and session, as needed, in order to assure the password 
# requirements will be applied to it.
    
#######################DISA INFORMATION##################################
	
# Global Variables
PDI=GEN000600-2
	
# Start-Lockdown

#####################################################################
# Set up custom config files if needed. This section will be appended
# to each script making pam config changes just in case.
#####################################################################

for PFPREFIX in system password smartcard fingerprint
do
  if [ -e "/etc/pam.d/${PFPREFIX}-auth-ac" ]
  then
    if [ ! -e "/etc/pam.d/${PFPREFIX}-auth-local" ]
    then
    
      cat <<EOF > /etc/pam.d/${PFPREFIX}-auth-local
auth          include       ${PFPREFIX}-auth-ac
account       include       ${PFPREFIX}-auth-ac
password      include       ${PFPREFIX}-auth-ac
session       include       ${PFPREFIX}-auth-ac
EOF

      ln -f -s /etc/pam.d/${PFPREFIX}-auth-local /etc/pam.d/${PFPREFIX}-auth
      chown root:root /etc/pam.d/${PFPREFIX}-auth-local
      chmod 644 /etc/pam.d/${PFPREFIX}-auth-local
      chcon system_u:object_r:etc_t /etc/pam.d/${PFPREFIX}-auth-local

    fi
  fi
done


